@@ -64,7 +64,7 @@ static struct option program_options[] = {
 /* Function to print the version - near the top for easy modification. */
 void PrintVersion(char* ProgramName)
 {
-	printf("%s, v 1.5.4, 22 July 2007. Daniel Foote, 2005-2007. GNU GPL.\n", ProgramName);
+	printf("%s, v 1.5.6, 22 July 2007. Daniel Foote, 2005-2007. GNU GPL.\n", ProgramName);
 }
 
 /* Function to print the usage info. */
@@ -243,7 +243,7 @@ int main(int argc, char** argv)
 	{
 		/* Call getopt to do all the hard work
 		 * for us... */
-		c = getopt_long(argc, argv, "g:z:ihvd:m:nsortMVfO",
+		c = getopt_long(argc, argv, "g:z:ihvd:m:nsortMVfO:",
 				program_options, 0);
 
 		if (c == -1) break;
@@ -396,6 +396,8 @@ int main(int argc, char** argv)
 		{
 			/* Found colon. Split into two. */
 			sscanf(TimeAdjustment, "%d:%d", &TimeZoneHours, &TimeZoneMins);
+			if (TimeZoneHours < 0)
+			    TimeZoneMins *= -1;
 		} else {
 			/* No colon. Just parse. */
 			TimeZoneHours = atoi(TimeAdjustment);
@@ -421,6 +423,8 @@ int main(int argc, char** argv)
 		{
 			/* Found colon. Split into two. */
 			sscanf(TimeAdjustment, "%d:%d", &TimeZoneHours, &TimeZoneMins);
+			if (TimeZoneHours < 0)
+			    TimeZoneMins *= -1;
 		} else {
 			/* No colon. Just parse. */
 			TimeZoneHours = atoi(TimeAdjustment);
